@@ -8,10 +8,12 @@ from itertools import count, cycle
 from math import ceil, floor, radians
 from pathlib import Path
 from subprocess import Popen
+from typing import Union
 
 import requests
 from cachecontrol import CacheControl
 from PIL import Image, ImageDraw, ImageFont
+from PIL.ImageFont import FreeTypeFont
 
 from .constants import *
 from .defaults import *
@@ -43,6 +45,7 @@ class PaperMap(object):
         nb_retries: int = NB_RETRIES_DEFAULT,
         landscape: bool = False,
         quiet: bool = False,
+        font: FreeTypeFont = FONT_DEFAULT,
         gpx: GPX = None,
         **kwargs
     ) -> None:
@@ -81,6 +84,7 @@ class PaperMap(object):
         self.nb_retries = nb_retries
         self.use_landscape = landscape
         self.quiet_mode = quiet
+        self.font = font
         self.gpx = gpx
 
         # get the right tile server
@@ -272,7 +276,6 @@ class PaperMap(object):
 
             draw = ImageDraw.Draw(self.map_image)
             color = '#000'
-            font = ImageFont.truetype('arial.ttf', 35)
 
             # draw vertical grid lines
             for x, label in x_grid_cs_and_labels:
@@ -280,11 +283,11 @@ class PaperMap(object):
                 draw.line(((x, 0), (x, self.im_height)), fill=color)
 
                 # draw grid label
-                text_size = draw.textsize(label, font=font)
+                text_size = draw.textsize(label, font=self.font)
                 draw.rectangle(
                     [(x - text_size[0] / 2, 0), (x + text_size[0] / 2, text_size[1])], fill='#fff')
                 draw.text((x - text_size[0] / 2, 0),
-                          label, font=font, fill=color)
+                          label, font=self.font, fill=color)
 
             # draw horizontal grid lines
             for y, label in y_grid_cs_and_labels:
@@ -292,10 +295,10 @@ class PaperMap(object):
                 draw.line(((0, y), (self.im_width, y)), fill=color)
 
                 # draw grid label
-                text_size = draw.textsize(label, font=font)
+                text_size = draw.textsize(label, font=self.font)
                 text_image = Image.new('RGB', text_size, '#fff')
                 text_draw = ImageDraw.Draw(text_image)
-                text_draw.text((0, 0), label, font=font, fill=color)
+                text_draw.text((0, 0), label, font=self.font, fill=color)
                 text_image = text_image.rotate(90, expand=1)
                 self.map_image.paste(
                     text_image, (0, int(y - text_size[0] / 2)))
@@ -308,10 +311,9 @@ class PaperMap(object):
         """
         draw = ImageDraw.Draw(self.map_image)
         color = '#000'
-        font = ImageFont.truetype('arial.ttf', 35)
 
         text = f'{self.tile_server["attribution"]}. Created with PaperMap. Scale: 1:{self.scale}'
-        text_size = draw.textsize(text, font=font)
+        text_size = draw.textsize(text, font=self.font)
         if text_size[0] <= self.im_width:
             draw.rectangle(
                 [(self.im_width - text_size[0], self.im_height -
@@ -319,7 +321,7 @@ class PaperMap(object):
                 fill='#fff'
             )
             draw.text(
-                (self.im_width - text_size[0], self.im_height - text_size[1]), text, font=font, fill=color)
+                (self.im_width - text_size[0], self.im_height - text_size[1]), text, font=self.font, fill=color)
         del draw
 
     def download_tiles(self):
@@ -384,7 +386,6 @@ class PaperMap(object):
                 self.map_image_scaled,
                 (self.x_center, self.y_center),
                 self.zoom_scaled,
-                self.dpi,
                 TILE_SIZE
             )
             # render the waypoints
@@ -392,7 +393,6 @@ class PaperMap(object):
                 self.map_image_scaled,
                 (self.x_center, self.y_center),
                 self.zoom_scaled,
-                self.dpi,
                 TILE_SIZE
             )
 
@@ -470,6 +470,8 @@ def main():
                         help='Coordinate grid to display on the paper map')
     parser.add_argument('-w', '--nb_workers', type=int, default=NB_WORKERS_DEFAULT,
                         metavar='NUMBER', help='Number of workers (for parallelization)')
+    parser.add_argument('-f', '--font', type=str, default=str(FONT_FILE_DEFAULT),
+                        metavar='PATH', help='Filename or -path to the font')
     parser.add_argument('-o', '--open', action='store_true',
                         help='Open paper map after generating')
     parser.add_argument('-l', '--landscape', action='store_true',
@@ -528,6 +530,14 @@ def main():
         raise ValueError(
             'Invalid input method. Please choose one of: wgs84, utm, rd or gpx')
 
+    # parse font
+    try:
+        args.font = ImageFont.truetype(args.font, FONT_SIZE_DEFAULT)
+    except OSError:
+        if not args.quiet:
+            raise ValueError(f'Either {args.font} does not exist, or it is not a TrueType or OpenType font.')
+        sys.exit()
+
     # initialize the paper map
     pm = PaperMap(**vars(args))
 
